//
//  GameScene.swift
//  pong_try
//
//  Created by Anastasia T on 20/6/18.
//  Copyright © 2018 Anastassia Terzi. All rights reserved.
//
//basic game scene

import SpriteKit
import GameplayKit


class GameScene: SKScene {
    //variable declaration
    var ball = SKSpriteNode()
    var enemy = SKSpriteNode()
    var friend = SKSpriteNode()
    var score = [Int]()
    var top_lab = SKLabelNode()
   var bottom_lab = SKLabelNode()
        
    override func didMove(to view: SKView) {
       
        ball = self.childNode(withName: "ball") as! SKSpriteNode
        
        //positioning paddles
        enemy = self.childNode(withName: "enemy") as! SKSpriteNode
        enemy.position.y = (self.frame.height / 2) - 50
        
        friend = self.childNode(withName: "friend") as! SKSpriteNode
        friend.position.y = (-self.frame.height / 2)  + 50
        
        //positioning score labels
        top_lab = self.childNode(withName: "top_label") as! SKLabelNode
        bottom_lab = self.childNode(withName: "bottom_label") as! SKLabelNode
        
        //setting physics body of borders
        let border = SKPhysicsBody(edgeLoopFrom: self.frame)
        border.friction = 0
        border.restitution = 1
        self.physicsBody = border
        
        //starting game
         startGame()
        
        }
   //setting game
    func startGame(){
        
        score = [ 0, 0 ]
        top_lab.text = "\(score[1])"
        bottom_lab.text = "\(score[0])"
        ball.physicsBody?.applyImpulse(CGVector(dx: 20, dy: 20))

    }
    
    func add_score(player_Won : SKSpriteNode){
        
       //positioning ball in the center
        ball.position = CGPoint( x: 0, y: 0 )
        ball.physicsBody?.velocity = CGVector (dx: 0, dy: 0)
        
        //adding score to player2 or friend
        if player_Won == friend {
            score[0] += 1
            ball.physicsBody?.applyImpulse(CGVector(dx: 20, dy: 20))
        }
        //adding score to player1 or enemy
        else if player_Won == enemy{
            score[1] += 1
            ball.physicsBody?.applyImpulse(CGVector(dx: -20, dy: -20))
            
        }
      top_lab.text = "\(score[1])"
      bottom_lab.text = "\(score[0])"
        
        //case of ending the game
        //changing to winning scene for player2
        if score[0] == 10{
            let gameOverScene = GameOverScene(size: self.size, won: true)
            self.view?.presentScene(gameOverScene)
        }
         //changing to winning scene for player1
        if score[1] == 10{
            let gameOverScene = GameOverScene(size: self.size, won: false)
            self.view?.presentScene(gameOverScene)
        }
    }
    
    //activate action
    override func touchesBegan(_ touches: Set<UITouch>, with event: UIEvent?) {
        for touch in touches {
            let location = touch.location(in: self)
            //case for two players
            if currentGameType == .player2{
                if location.y  > 0 {
                    enemy.run(SKAction.moveTo(x: location.x, duration: 0.2))}
                if location.y < 0{
                    friend.run(SKAction.moveTo(x: location.x, duration: 0.2))}
            }
                //case for playing against cpu
                else {
                  friend.run(SKAction.moveTo(x: location.x, duration: 0.2))}
        }
    }
    
    //manage touch movement
    override func touchesMoved(_ touches: Set<UITouch>, with event: UIEvent?) {
        for touch in touches {
            
            let location = touch.location(in: self)
             //case for two players and moving the paddles
            if currentGameType == .player2{
                if location.y  > 0 {
                    enemy.run(SKAction.moveTo(x: location.x, duration: 0.2))}
                if location.y < 0{
                     friend.run(SKAction.moveTo(x: location.x, duration: 0.2))}
            }
                //case for playing against cpu moving the paddle
                else {
                     friend.run(SKAction.moveTo(x: location.x, duration: 0.2))}
            }
    }
    
    override func update(_ currentTime: TimeInterval) {
        //case for game type
        switch currentGameType {
        case .easy:
               enemy.run(SKAction.moveTo(x: ball.position.x , duration: 1.3))
            break
        case .medium:
               enemy.run(SKAction.moveTo(x: ball.position.x , duration: 1.0))
            break
        case .hard:
               enemy.run(SKAction.moveTo(x: ball.position.x , duration: 0.7))
            break
        case .player2:
            
            break
        }
        //case for adding score to right player
        if ball.position.y <= friend.position.y - 30 {
            add_score(player_Won: enemy)
        }
            
        else if ball.position.y >= enemy.position.y + 30 {
            
            add_score(player_Won: friend)
            
        }
    }
}
